function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import { styled } from '../styles/index.js';
import { startThumbIcon, endThumbIcon, singleThumbIcon } from './icons.js';
export var Root = styled('div', function (props) {
  return {
    paddingTop: '1px',
    position: 'relative'
  };
});
Root.displayName = "Root";
Root.displayName = 'StyledRoot';
export var Axis = styled('div', function (props) {
  var $theme = props.$theme;
  var colors = $theme.colors,
      borders = $theme.borders,
      sizing = $theme.sizing;
  return {
    position: 'relative',
    marginTop: sizing.scale900,
    marginBottom: sizing.scale900,
    marginRight: sizing.scale400,
    marginLeft: sizing.scale400,
    borderRadius: $theme.borders.useRoundedCorners ? borders.radius100 : '0px',
    backgroundColor: colors.mono400,
    height: sizing.scale100
  };
});
Axis.displayName = "Axis";
Axis.displayName = 'StyledAxis';
export var AxisRange = styled('div', function (props) {
  var $max = props.$max,
      $min = props.$min,
      $index = props.$index,
      $isRange = props.$isRange,
      $value = props.$value,
      $theme = props.$theme;
  var colors = $theme.colors,
      borders = $theme.borders,
      sizing = $theme.sizing;
  var fillColor = colors.primary400;
  var emptyColor = colors.mono400;
  var barColor;

  if ($isRange) {
    barColor = $index % 2 === 0 ? emptyColor : fillColor;
  } else {
    barColor = $index % 2 === 0 ? fillColor : emptyColor;
  }

  var value = $isRange && $index ? $value[$index] - $value[$index - 1] : $value[$index];
  var totalRangeValue = $max - $min;
  var width = "".concat(value / totalRangeValue * 100, "%");
  var offset = $isRange && $index ? "".concat($value[$index - 1] / totalRangeValue * 100, "%") : null;
  return {
    borderRadius: borders.useRoundedCorners ? sizing.scale0 : '0',
    height: '100%',
    position: 'absolute',
    top: '0',
    marginLeft: offset,
    backgroundColor: barColor,
    width: width
  };
});
AxisRange.displayName = "AxisRange";
AxisRange.displayName = 'StyledAxisRange';
export var Tick = styled('div', function (props) {
  return {};
});
Tick.displayName = "Tick";
Tick.displayName = 'StyledTick';
export var TickBar = styled('div', function (props) {
  var $theme = props.$theme;
  var sizing = $theme.sizing;
  return {
    display: 'flex',
    justifyContent: 'space-between',
    alignItems: 'center',
    marginTop: sizing.scale400,
    marginBottom: sizing.scale400,
    marginRight: sizing.scale400,
    marginLeft: sizing.scale400
  };
});
TickBar.displayName = "TickBar";
TickBar.displayName = 'StyledTickBar';
export var Thumb = styled('div', function (props) {
  var $theme = props.$theme,
      $value = props.$value,
      $max = props.$max,
      $index = props.$index,
      $currentThumb = props.$currentThumb,
      $disabled = props.$disabled,
      $isRange = props.$isRange;
  var $isActive = $index === $currentThumb;
  var offset = Math.round($value[$index] / $max * 100);
  var animation = $theme.animation,
      colors = $theme.colors,
      sizing = $theme.sizing;
  var backgroundColor = $disabled ? colors.mono500 : colors.white;
  var thumbColor = getThumbColor(_objectSpread({}, props, {
    $isActive: $isActive
  }));
  var toggleSVG = '';
  var $isStart = $isRange && $index % 2 === 0;
  var $isEnd = $isRange && $index % 2 !== 0;

  if ($isStart) {
    toggleSVG = startThumbIcon(backgroundColor, thumbColor);
  } else if ($isEnd) {
    toggleSVG = endThumbIcon(backgroundColor, thumbColor);
  } else {
    toggleSVG = singleThumbIcon(backgroundColor, thumbColor);
  }

  return {
    transitionDuration: animation.timing100,
    transitionTimingFunction: animation.easeOutCurve,
    transitionProperty: 'background-color',
    ':after': {
      position: 'absolute',
      content: "url('data:image/svg+xml;utf8,".concat(toggleSVG, "')")
    },
    position: 'relative',
    top: '-14px',
    cursor: 'pointer',
    zIndex: '1',
    left: "".concat(offset, "%"),
    marginLeft: $isRange ? '-8px' : $index % 2 ? '-32px' : '-16px',
    ':before': {
      position: 'absolute',
      content: "\"".concat(Math.round($value[$index]), "\""),
      top: '-14px',
      marginLeft: sizing.scale100,
      width: sizing.scale600,
      height: sizing.scale600
    }
  };
});
Thumb.displayName = "Thumb";
Thumb.displayName = 'StyledThumb';

function getThumbColor(props) {
  var $disabled = props.$disabled,
      $isFocused = props.$isFocused,
      $isError = props.$isError,
      $isHovered = props.$isHovered,
      $isActive = props.$isActive,
      $theme = props.$theme;
  var colors = $theme.colors;

  if ($disabled) {
    return colors.mono600;
  } else if ($isActive || $isFocused || $isHovered) {
    return colors.primary400;
  } else if ($isError) {
    if ($isActive || $isFocused) {
      return colors.negative200;
    } else if ($isHovered) {
      return colors.negative100;
    } else {
      return colors.negative50;
    }
  } else {
    return colors.mono600;
  }
}