function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
Copyright (c) 2018 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import * as React from 'react';
import { shallow } from 'enzyme';
import { Caption1, Caption2, Display, H1, H2, H3, H4, H5, H6, Label1, Label2, Paragraph1, Paragraph2 } from '../index.js';
import Block from '../../block/block.js';

function getStyle(element) {
  return shallow(element).find(Block).props();
}

var BASIC_TESTS = {
  Caption1: {
    as: 'div',
    font: 'font200',
    children: 'test',
    overrides: {}
  },
  Caption2: {
    as: 'div',
    font: 'font250',
    children: 'test',
    overrides: {}
  },
  Display: {
    as: 'div',
    font: 'font1100',
    children: 'test',
    overrides: {}
  },
  H1: {
    as: 'h1',
    font: 'font1000',
    children: 'test',
    overrides: {}
  },
  H2: {
    as: 'h2',
    font: 'font900',
    children: 'test',
    overrides: {}
  },
  H3: {
    as: 'h3',
    font: 'font800',
    children: 'test',
    overrides: {}
  },
  H4: {
    as: 'h4',
    font: 'font700',
    children: 'test',
    overrides: {}
  },
  H5: {
    as: 'h5',
    font: 'font600',
    children: 'test',
    overrides: {}
  },
  H6: {
    as: 'h6',
    font: 'font500',
    children: 'test',
    overrides: {}
  },
  Label1: {
    as: 'div',
    font: 'font350',
    children: 'test',
    overrides: {}
  },
  Label2: {
    as: 'div',
    font: 'font450',
    children: 'test',
    overrides: {}
  },
  Paragraph1: {
    as: 'p',
    font: 'font300',
    children: 'test',
    overrides: {}
  },
  Paragraph2: {
    as: 'p',
    font: 'font400',
    children: 'test',
    overrides: {}
  }
};
describe('Typography', function () {
  it('Caption1 - shallow rendering with appropriate font', function () {
    expect(getStyle(React.createElement(Caption1, null, "test"))).toEqual(BASIC_TESTS.Caption1);
    expect(getStyle(React.createElement(Caption1, {
      color: "primary"
    }, "test"))).toEqual(_objectSpread({}, BASIC_TESTS.Caption1, {
      color: 'primary'
    }));
  });
  it('Caption2 - shallow rendering with appropriate font', function () {
    expect(getStyle(React.createElement(Caption2, null, "test"))).toEqual(BASIC_TESTS.Caption2);
    expect(getStyle(React.createElement(Caption2, {
      padding: "6px"
    }, "test"))).toEqual(_objectSpread({}, BASIC_TESTS.Caption2, {
      padding: '6px'
    }));
  });
  it('Display - shallow rendering with appropriate font', function () {
    expect(getStyle(React.createElement(Display, null, "test"))).toEqual(BASIC_TESTS.Display);
    expect(getStyle(React.createElement(Display, {
      paddingLeft: "20px"
    }, "test"))).toEqual(_objectSpread({}, BASIC_TESTS.Display, {
      paddingLeft: '20px'
    }));
  });
  it('H1 - shallow rendering with appropriate font', function () {
    expect(getStyle(React.createElement(H1, null, "test"))).toEqual(BASIC_TESTS.H1);
    expect(getStyle(React.createElement(H1, {
      marginTop: "30px"
    }, "test"))).toEqual(_objectSpread({}, BASIC_TESTS.H1, {
      marginTop: '30px'
    }));
  });
  it('H2 - shallow rendering with appropriate font', function () {
    expect(getStyle(React.createElement(H2, null, "test"))).toEqual(BASIC_TESTS.H2);
    expect(getStyle(React.createElement(H2, {
      position: "absolute",
      bottom: "0",
      left: "10px"
    }, "test"))).toEqual(_objectSpread({}, BASIC_TESTS.H2, {
      position: 'absolute',
      bottom: '0',
      left: '10px'
    }));
  });
  it('H3 - shallow rendering with appropriate font', function () {
    expect(getStyle(React.createElement(H3, null, "test"))).toEqual(BASIC_TESTS.H3);
    expect(getStyle(React.createElement(H3, {
      position: "sticky",
      top: "4rem"
    }, "test"))).toEqual(_objectSpread({}, BASIC_TESTS.H3, {
      position: 'sticky',
      top: '4rem'
    }));
  });
  it('H4 - shallow rendering with appropriate font', function () {
    expect(getStyle(React.createElement(H4, null, "test"))).toEqual(BASIC_TESTS.H4);
    expect(getStyle(React.createElement(H4, {
      maxWidth: "30px"
    }, "test"))).toEqual(_objectSpread({}, BASIC_TESTS.H4, {
      maxWidth: '30px'
    }));
  });
  it('H5 - shallow rendering with appropriate font', function () {
    expect(getStyle(React.createElement(H5, null, "test"))).toEqual(BASIC_TESTS.H5);
    expect(getStyle(React.createElement(H5, {
      minWidth: "20px"
    }, "test"))).toEqual(_objectSpread({}, BASIC_TESTS.H5, {
      minWidth: '20px'
    }));
  });
  it('H6 - shallow rendering with appropriate font', function () {
    expect(getStyle(React.createElement(H6, {
      minHeight: "30px"
    }, "test"))).toEqual(_objectSpread({}, BASIC_TESTS.H6, {
      minHeight: '30px'
    }));
  });
  it('Label1 - shallow rendering with appropriate font', function () {
    expect(getStyle(React.createElement(Label1, null, "test"))).toEqual(BASIC_TESTS.Label1);
    expect(getStyle(React.createElement(Label1, {
      marginBottom: "20px",
      paddingTop: "10px"
    }, "test"))).toEqual(_objectSpread({}, BASIC_TESTS.Label1, {
      marginBottom: '20px',
      paddingTop: '10px'
    }));
  });
  it('Label2 - shallow rendering with appropriate font', function () {
    expect(getStyle(React.createElement(Label2, null, "test"))).toEqual(BASIC_TESTS.Label2);
    expect(getStyle(React.createElement(Label2, {
      marginLeft: "10px",
      paddingRight: "20px"
    }, "test"))).toEqual(_objectSpread({}, BASIC_TESTS.Label2, {
      marginLeft: '10px',
      paddingRight: '20px'
    }));
  });
  it('Paragraph1 - shallow rendering with appropriate font', function () {
    expect(getStyle(React.createElement(Paragraph1, null, "test"))).toEqual(BASIC_TESTS.Paragraph1);
    expect(getStyle(React.createElement(Paragraph1, {
      margin: "10px 4px",
      width: "200px"
    }, "test"))).toEqual(_objectSpread({}, BASIC_TESTS.Paragraph1, {
      margin: '10px 4px',
      width: '200px'
    }));
  });
  it('Paragraph2 - shallow rendering with appropriate font', function () {
    expect(getStyle(React.createElement(Paragraph2, null, "test"))).toEqual(BASIC_TESTS.Paragraph2);
    expect(getStyle(React.createElement(Paragraph2, {
      alignSelf: "center",
      justifySelf: "flex-end"
    }, "test"))).toEqual(_objectSpread({}, BASIC_TESTS.Paragraph2, {
      alignSelf: 'center',
      justifySelf: 'flex-end'
    }));
  });
});